@@ -9,7 +9,8 @@ class RequestsStrategy(object):
         self.environment = environment
 
     def http_do(self, http_verb, path, headers, request_body):
-        response = self.__request_function(http_verb)(
+        response = requests.request(
+            http_verb,
             self.environment.base_url + path,
             headers=headers,
             data=request_body,
@@ -17,13 +18,3 @@ class RequestsStrategy(object):
         )
 
         return [response.status_code, response.text]
-
-    def __request_function(self, method):
-        if method == "GET":
-            return requests.get
-        elif method == "POST":
-            return requests.post
-        elif method == "PUT":
-            return requests.put
-        elif method == "DELETE":
-            return requests.delete
