@@ -1,7 +1,6 @@
 from tests.test_helper import *
 
 class TestAddOn(unittest.TestCase):
-
     def test_all_returns_all_add_ons(self):
         new_id = str(random.randint(1, 1000000))
         attributes = {
@@ -20,14 +19,16 @@ class TestAddOn(unittest.TestCase):
 
         for add_on in add_ons:
             if add_on.id == new_id:
-                actual_add_on = add_on
+                break
+        else:
+            add_on = None
 
-        self.assertNotEquals(None, actual_add_on)
+        self.assertNotEquals(None, add_on)
 
-        self.assertEquals(attributes["amount"], "100.00")
-        self.assertEquals(attributes["description"], "some description")
-        self.assertEquals(attributes["id"], new_id)
-        self.assertEquals(attributes["kind"], "add_on")
-        self.assertEquals(attributes["name"], "python_add_on")
-        self.assertEquals(attributes["never_expires"], False)
-        self.assertEquals(attributes["number_of_billing_cycles"], 1)
+        self.assertEquals(add_on.amount, Decimal("100.00"))
+        self.assertEquals(add_on.description, "some description")
+        self.assertEquals(add_on.id, new_id)
+        self.assertEquals(add_on.kind, "add_on")
+        self.assertEquals(add_on.name, "python_add_on")
+        self.assertEquals(add_on.never_expires, False)
+        self.assertEquals(add_on.number_of_billing_cycles, 1)
