@@ -45,7 +45,7 @@ class TestPyCurl(CommonHttpTests, unittest.TestCase):
         if platform.system() == "Darwin":
             return
 
-        environment = Environment(Environment.Sandbox.server, "443", True, Environment.Production.ssl_certificate)
+        environment = Environment("www.google.com", "443", True, Environment.Production.ssl_certificate)
         http = self.get_http(environment)
         try:
             http.get("/")
@@ -59,7 +59,8 @@ class TestPyCurl(CommonHttpTests, unittest.TestCase):
             self.fail("Expected to receive an SSL error but no exception was raised")
 
     def test_unsuccessful_connection_to_ssl_server_with_wrong_domain(self):
-        environment = Environment("braintreegateway.com", "443", True, Environment.Production.ssl_certificate)
+        #ip address of api.braintreegateway.com
+        environment = Environment("204.109.13.121", "443", True, Environment.Production.ssl_certificate)
         http = self.get_http(environment)
         try:
             http.get("/")
@@ -85,7 +86,7 @@ class TestRequests(CommonHttpTests, unittest.TestCase):
         if platform.system() == "Darwin":
             return
 
-        environment = Environment(Environment.Sandbox.server, "443", True, Environment.Production.ssl_certificate)
+        environment = Environment("www.google.com", "443", True, Environment.Production.ssl_certificate)
         http = self.get_http(environment)
         try:
             http.get("/")
@@ -97,7 +98,8 @@ class TestRequests(CommonHttpTests, unittest.TestCase):
             self.fail("Expected to receive an SSL error but no exception was raised")
 
     def test_unsuccessful_connection_to_ssl_server_with_wrong_domain(self):
-        environment = Environment("www.braintreepayments.com", "443", True, Environment.Production.ssl_certificate)
+        #ip address of api.braintreegateway.com
+        environment = Environment("204.109.13.121", "443", True, Environment.Production.ssl_certificate)
         http = self.get_http(environment)
         try:
             http.get("/")
